@@ -8,4 +8,6 @@ MODEL_WATCH_INTERVAL_S = 1
 REQUIREMENTS_RETURN_CODE_SUCCESS = 0
 REQUIREMENTS_RETURN_CODE_MISSING_DEP = 1
 REQUIREMENTS_RETURN_CODE_IMPORT_ERROR = 2
-REQUIREMENTS_RETURN_CODE_EXIT = 3
+REQUIREMENTS_RETURN_CODE_FILE_NOT_FOUND_ERROR = 3
+REQUIREMENTS_RETURN_CODE_UNKNOWN_ERROR = 4
+REQUIREMENTS_RETURN_CODE_EXIT = 5
