@@ -118,8 +118,8 @@ class LocalConfigHelper:
     def _create_google_drive_folder(self):
         log.action("Creating project folder in google drive")
 
-        project_folder_id = self.drive_client.create_folder(
-            name=f"slai-{self.service_name}"
+        project_folder_id = self.drive_client.create_project_folder(
+            folder_name=f"slai-{self.service_name}"
         )
 
         log.action("Done.")
