@@ -18,6 +18,10 @@ def _check_imports(*, model_name, model_version_id, docker_client):
     exit_code = docker_client.check_trainer_imports(
         model_name=model_name, model_version_id=model_version_id
     )
+    import pdb
+
+    pdb.set_trace()
+
     if exit_code == constants.REQUIREMENTS_RETURN_CODE_MISSING_DEP:
         if log.action_confirm(
             "Looks like a dependency is missing, would you like to add it interactively?"
@@ -33,7 +37,11 @@ def _check_imports(*, model_name, model_version_id, docker_client):
             )
         else:
             return constants.REQUIREMENTS_RETURN_CODE_EXIT
-
+    elif exit_code == constants.REQUIREMENTS_RETURN_CODE_FILE_NOT_FOUND_ERROR:
+        log.warn(
+            "Trainer script not found, run `slai model save <model_name>` to generate a training script."  # noqa
+        )
+        return constants.REQUIREMENTS_RETURN_CODE_EXIT
     elif exit_code == constants.REQUIREMENTS_RETURN_CODE_IMPORT_ERROR:
         log.warn("Trainer script failed due to import error.")
         return constants.REQUIREMENTS_RETURN_CODE_EXIT
